@@ -2,7 +2,7 @@ package Finance::InteractiveBrokers::SWIG;
 #
 #   Finance::InteractiveBrokers::SWIG - InteractiveBrokers C++ connector
 #
-#   Copyright (c) 2010-2012 Jason McManus
+#   Copyright (c) 2010-2011 Jason McManus
 #
 #   Full POD documentation after __END__
 #
@@ -10,7 +10,7 @@ package Finance::InteractiveBrokers::SWIG;
 use Data::Dumper;
 use Carp qw( croak confess longmess );
 use Socket qw( inet_ntoa inet_aton );
-use Net::hostent ();
+use Net::hostent;
 use strict;
 use warnings;
 
@@ -24,7 +24,7 @@ use Finance::InteractiveBrokers::SWIG::IBAPI;   # SWIG module
 
 use vars qw( $VERSION $AUTOLOAD $TRUE $FALSE $KEEP $DELETE $REQUIRED );
 BEGIN {
-    $VERSION  = '0.06_01';
+    $VERSION  = '0.02';
 }
 
 *TRUE     = \1;
@@ -155,7 +155,7 @@ sub api_methods
 
     # Version was valid, show the methods
     if( -t STDIN and -t STDOUT ) {
-        print "InteractiveBrokers API methods callable for API version $version:\n";
+        print "IB API methods callable for API version $version:\n";
         print "    $_\n" for( @methods );
     }
 
@@ -169,10 +169,10 @@ sub _resolve_host
     my $whatever = shift;
     my( $hostname, @addresses );
 
-    if( my $hent = Net::hostent::gethost( $whatever ) )
+    if( my $hent = gethostbyname( $whatever ) )
     {
         $hostname  = $hent->name;
-        @addresses = map { inet_ntoa( $_ ) } @{ $hent->addr_list };
+        @addresses = map { inet_ntoa( $_ ) } $hent->addr_list;
     }
 
     return( $hostname, @addresses );
@@ -300,13 +300,13 @@ Then:
     $ib->reqCurrentTime();
 
     # Your event loop here
-    $ib->processMessages()
+    $ib->processMessags()
         while( $ib->isConnected() );
 
     # And eventually...
     $ib->eDisconnect();
 
-See the F<examples/> directory in this distribution for more complete and
+See the C<examples/> directory in this distribution for more complete and
 well-commented examples.
 
 =head1 DESCRIPTION
@@ -354,10 +354,10 @@ Provides a programmatic means of looking up methods and events in the IB API.
 
 Capable of compiling C and C++ files, and running 'make'.
 
-=item * SWIG >= 1.3.28
+=item * SWIG >= 1.3.36
 
 The "Simplified Wrapper and Interface Generator", capable of building SWIG
-interfaces.  This module has been tested with SWIG versions 1.3.28 - 2.0.1.
+interfaces.  This module has been tested with SWIG versions 1.3.36 - 2.0.1.
 
 =back
 
@@ -391,7 +391,7 @@ L<Finance::InteractiveBrokers::SWIG::EventHandler>.  It is delegated to when
 receiving events from the IB service.
 
 Please see L<Finance::InteractiveBrokers::SWIG::EventHandler> for notes on
-how to subclass it, and the F<examples/> directory of this distribution.
+how to subclass it, and the C<examples/> directory of this distribution.
 
 B<RETURNS:> blessed C<$object>, or C<undef> on failure.
 
@@ -470,7 +470,7 @@ L<http://www.interactivebrokers.com/> - The InteractiveBrokers website
 
 L<http://www.interactivebrokers.com/php/apiUsersGuide/apiguide.htm> - The IB API documentation
 
-The F<examples/> directory of this module's distribution.
+The C<examples/> directory of this module's distribution.
 
 =head1 AUTHORS
 
@@ -483,22 +483,6 @@ C<bug-finance-interactivebrokers-swig at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Finance-InteractiveBrokers-SWIG>.  The authors will be notified, and then you'll
 automatically be notified of progress on your bug as changes are made.
 
-If you are sending a bug report, please include:
-
-=over 4
-
-=item * Your OS type, version, Perl version, and other similar information.
-
-=item * The version of Finance::InteractiveBrokers::SWIG you are using.
-
-=item * The version of the InteractiveBrokers API you are using.
-
-=item * If possible, a minimal test script which demonstrates your problem.
-
-=back
-
-This will be of great assistance in troubleshooting your issue.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -529,7 +513,7 @@ L<http://search.cpan.org/dist/Finance-InteractiveBrokers-SWIG/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2012 Jason McManus
+Copyright (c) 2010-2011 Jason McManus
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
